/*
   SPDX-FileCopyrightText: 2013-2026 Laurent Montel <montel@kde.org>

   SPDX-License-Identifier: GPL-2.0-or-later
*/
#pragma once

#include <QStringList>

namespace DefaultCompletion
{
[[nodiscard]] QStringList defaultCompetion();
[[nodiscard]] QStringList defaultOptions();
}
