// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "contactprintthemeeditor_debug.h"


Q_LOGGING_CATEGORY(CONTACTPRINTTHEMEEDITOR_LOG, "org.kde.pim.contactprintthemeeditor", QtInfoMsg)

