/********************************************************************************
** Form generated from reading UI file 'configurewidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONFIGUREWIDGET_H
#define UI_CONFIGUREWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "klineedit.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_ConfigureWidget
{
public:
    QGridLayout *gridLayout;
    QLabel *label;
    KLineEdit *authorEmail;
    KUrlRequester *defaultPath;
    QLabel *label_2;
    KLineEdit *author;
    QLabel *label_3;

    void setupUi(QWidget *ConfigureWidget)
    {
        if (ConfigureWidget->objectName().isEmpty())
            ConfigureWidget->setObjectName("ConfigureWidget");
        ConfigureWidget->resize(383, 85);
        gridLayout = new QGridLayout(ConfigureWidget);
        gridLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(ConfigureWidget);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        authorEmail = new KLineEdit(ConfigureWidget);
        authorEmail->setObjectName("authorEmail");
        authorEmail->setProperty("showClearButton", QVariant(true));
        authorEmail->setTrapReturnKey(true);

        gridLayout->addWidget(authorEmail, 2, 1, 1, 1);

        defaultPath = new KUrlRequester(ConfigureWidget);
        defaultPath->setObjectName("defaultPath");
        defaultPath->setMode(KFile::Directory|KFile::LocalOnly);

        gridLayout->addWidget(defaultPath, 0, 1, 1, 1);

        label_2 = new QLabel(ConfigureWidget);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 2, 0, 1, 1);

        author = new KLineEdit(ConfigureWidget);
        author->setObjectName("author");
        author->setClearButtonEnabled(true);
        author->setTrapReturnKey(true);

        gridLayout->addWidget(author, 1, 1, 1, 1);

        label_3 = new QLabel(ConfigureWidget);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 1, 0, 1, 1);

        QWidget::setTabOrder(defaultPath, author);
        QWidget::setTabOrder(author, authorEmail);

        retranslateUi(ConfigureWidget);

        QMetaObject::connectSlotsByName(ConfigureWidget);
    } // setupUi

    void retranslateUi(QWidget *ConfigureWidget)
    {
        label->setText(tr2i18n("Default theme path:", nullptr));
        label_2->setText(tr2i18n("Author email:", nullptr));
        label_3->setText(tr2i18n("Author name:", nullptr));
        (void)ConfigureWidget;
    } // retranslateUi

};

namespace Ui {
    class ConfigureWidget: public Ui_ConfigureWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONFIGUREWIDGET_H

